@@ -13,10 +13,8 @@ constexpr int INFINITE_INT =  std::numeric_limits<int>::max ();
 
 namespace sf{
 
-double haversine (double x1, double y1, double x2, double y2);
 void fill_one_row (const R_xlen_t ngeoms, const Rcpp::NumericMatrix &gi,
-        const Rcpp::CharacterVector &rnms,
-        const double &d, const double &hw_factor,
+        const Rcpp::CharacterVector &rnms, const double &hw_factor,
         const std::string &hway, const bool &has_names,
         const std::vector <std::string> &way_names,
         const size_t &grownum, const size_t &rownum, const bool &reverse,
